You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jb...@apache.org on 2006/12/26 18:50:10 UTC

svn commit: r490343 - /incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java

Author: jboynes
Date: Tue Dec 26 09:50:09 2006
New Revision: 490343

URL: http://svn.apache.org/viewvc?view=rev&rev=490343
Log:
add contentType description to stream variant of AssemblyService

Modified:
    incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java

Modified: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java?view=diff&rev=490343&r1=490342&r2=490343
==============================================================================
--- incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java (original)
+++ incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java Tue Dec 26 09:50:09 2006
@@ -40,10 +40,13 @@
     /**
      * Apply a set of changes to the SCA Domain's logical assembly.
      *
      * @param changeSet a stream for reading a resource containing a set of changes; the stream will not be closed
      *                  but no guarantee is made on the position the stream is left in
      * @throws DeploymentException if there was a problem making the changes
      * @throws IOException         if there was a problem reading the stream
      */
-    void applyChanges(InputStream changeSet) throws DeploymentException, IOException;
+    void applyChanges(InputStream changeSet, String contentType) throws DeploymentException, IOException;
 }



---------------------------------------------------------------------
@@ -40,10 +40,13 @@
      * Apply a set of changes to the SCA Domain's logical assembly.
      *
-     * @param changeSet a stream for reading a resource containing a set of changes; the stream will not be closed
-     *                  but no guarantee is made on the position the stream is left in
+     * @param changeSet   a stream for reading a resource containing a set of changes; the stream will not be closed
+     *                    but no guarantee is made on the position the stream is left in
+     * @param contentType the type of changeSet on the stream; must be a valid Content-Type value
+     *                    as specified by <a href="http://www.ietf.org/rfc/rfc2045.txt">RFC2045</a>
+     *                    and must not be null
      * @throws DeploymentException if there was a problem making the changes
      * @throws IOException         if there was a problem reading the stream
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org